Prefix

Enum Prefix 

pub enum Prefix {
Show 16 variants Kilo, Mega, Giga, Tera, Peta, Exa, Zetta, Yotta, Kibi, Mebi, Gibi, Tebi, Pebi, Exbi, Zebi, Yobi,
}
A numeric prefix, either binary or decimal.

Variants



Kilo

kilo, 103 or 10001. From the Greek ‘χίλιοι’ (‘chilioi’), meaning ‘thousand’.



Mega

mega, 106 or 10002. From the Ancient Greek ‘μέγας’ (‘megas’), meaning ‘great’.



Giga

giga, 109 or 10003. From the Greek ‘γίγας’ (‘gigas’), meaning ‘giant’.



Tera

tera, 1012 or 10004. From the Greek ‘τέρας’ (‘teras’), meaning ‘monster’.



Peta

peta, 1015 or 10005. From the Greek ‘πέντε’ (‘pente’), meaning ‘five’.



Exa

exa, 1018 or 10006. From the Greek ‘ἕξ’ (‘hex’), meaning ‘six’.



Zetta

zetta, 1021 or 10007. From the Latin ‘septem’, meaning ‘seven’.



Yotta

yotta, 1024 or 10008. From the Green ‘οκτώ’ (‘okto’), meaning ‘eight’.



Kibi

kibi, 210 or 10241. The binary version of kilo.



Mebi

mebi, 220 or 10242. The binary version of mega.



Gibi

gibi, 230 or 10243. The binary version of giga.



Tebi

tebi, 240 or 10244. The binary version of tera.



Pebi

pebi, 250 or 10245. The binary version of peta.



Exbi

exbi, 260 or 10246. The binary version of exa.



Zebi

zebi, 270 or 10247. The binary version of zetta.



Yobi

yobi, 280 or 10248. The binary version of yotta.

Implementations

Source

impl Prefix

pub fn upper(self) -> &'static str

Returns the name in uppercase, such as “KILO”.

Examples
use unit_prefix::Prefix;

assert_eq!("GIGA", Prefix::Giga.upper());
assert_eq!("GIBI", Prefix::Gibi.upper());
pub fn caps(self) -> &'static str

Returns the name with the first letter capitalised, such as “Mega”.

Examples
use unit_prefix::Prefix;

assert_eq!("Giga", Prefix::Giga.caps());
assert_eq!("Gibi", Prefix::Gibi.caps());
pub fn lower(self) -> &'static str

Returns the name in lowercase, such as “giga”.

Examples
use unit_prefix::Prefix;

assert_eq!("giga", Prefix::Giga.lower());
assert_eq!("gibi", Prefix::Gibi.lower());
pub fn symbol(self) -> &'static str

Returns the short-hand symbol, such as “T” (for “tera”).

Examples
use unit_prefix::Prefix;

assert_eq!("G", Prefix::Giga.symbol());
assert_eq!("Gi", Prefix::Gibi.symbol());